@echo off
REM Jenkins Docker部署脚本 - Windows版本
REM 使用方法: deploy-jenkins.bat

echo 🚀 开始部署Jenkins with JDK 17...

REM 检查Docker是否运行
docker version >nul 2>&1
if errorlevel 1 (
    echo ❌ Docker未运行，请启动Docker Desktop
    pause
    exit /b 1
)

REM 创建数据目录
if not exist "jenkins_data" mkdir jenkins_data

echo 📁 创建Jenkins配置目录...

REM 拉取并运行Jenkins容器（使用官方镜像 + 安装JDK）
echo 🐳 启动Jenkins容器...

docker run -d ^
  --name jenkins-jdk17 ^
  --restart unless-stopped ^
  -p 15008:8080 ^
  -p 50000:50000 ^
  -v jenkins_data:/var/jenkins_home ^
  -v //var/run/docker.sock:/var/run/docker.sock ^
  -e JAVA_OPTS="-Djenkins.install.runSetupWizard=false -Xmx2048m" ^
  jenkins/jenkins:lts

echo ⏳ 等待Jenkins启动...
timeout /t 30 /nobreak

REM 在容器中安装JDK 17和其他工具
echo 🔧 安装JDK 17和构建工具...
docker exec -u root jenkins-jdk17 apt-get update
docker exec -u root jenkins-jdk17 apt-get install -y openjdk-17-jdk maven curl wget sshpass
docker exec -u root jenkins-jdk17 apt-get clean

REM 安装Docker CLI
docker exec -u root jenkins-jdk17 curl -fsSL https://get.docker.com -o get-docker.sh
docker exec -u root jenkins-jdk17 sh get-docker.sh
docker exec -u root jenkins-jdk17 usermod -aG docker jenkins

echo 📊 检查容器状态...
docker ps | findstr jenkins-jdk17

echo 🔑 获取Jenkins初始密码...
timeout /t 10 /nobreak
docker exec jenkins-jdk17 cat /var/jenkins_home/secrets/initialAdminPassword

echo.
echo ✅ Jenkins部署完成！
echo 🌐 访问地址: http://localhost:15008
echo.
echo 📋 预装环境:
echo    - OpenJDK 17
echo    - Maven 3.x
echo    - Docker CLI
echo    - Git
echo    - sshpass
echo.
echo 🔧 接下来请:
echo 1. 浏览器访问Jenkins
echo 2. 使用上面的初始密码登录
echo 3. 安装推荐插件
echo 4. 创建管理员用户
echo 5. 跳过工具配置（已预装）

pause
